MultiKeychain

Trait MultiKeychain 

pub trait MultiKeychain: Keychain {
    type PartialMultisignature: PartialMultisignature<Signature = Self::Signature>;

    // Required methods
    fn bootstrap_multi(
        &self,
        signature: &Self::Signature,
        index: NodeIndex,
    ) -> Self::PartialMultisignature;
    fn is_complete(
        &self,
        msg: &[u8],
        partial: &Self::PartialMultisignature,
    ) -> bool;
}
Extends Keychain with multisigning functionalities.

A single Signature can be raised to a Multisignature. Allows to verify whether a partial multisignature is complete (and valid).

Required Associated Types

Required Methods

fn bootstrap_multi( &self, signature: &Self::Signature, index: NodeIndex, ) -> Self::PartialMultisignature

Transform a single signature to a multisignature consisting of the signature.

fn is_complete(&self, msg: &[u8], partial: &Self::PartialMultisignature) -> bool

Checks if enough signatures have beed added.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors