pub trait FinalizationHandler<D>:
Sync
+ Send
+ 'staticwhere
D: Data,{
// Required method
fn data_finalized(&mut self, data: D);
}Expand description
The source of finalization of the units that consensus produces.
The FinalizationHandler::data_finalized method is called whenever a piece of data input
to the algorithm using DataProvider::get_data has been finalized, in order of finalization.
Required Methods
Sourcefn data_finalized(&mut self, data: D)
fn data_finalized(&mut self, data: D)
Data, provided by DataProvider::get_data, has been finalized. The calls to this function follow the order of finalization.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".